    /*

    Copyright (C) 2001 Matthias Kretz
                       kretz@kde.org

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
  
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
   
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

    */

#ifndef _KFADER_H
#define _KFADER_H

#include <tqslider.h>

class KFader : public TQSlider
{
	TQ_OBJECT
  
	protected:
		void init();
	public:
		KFader( TQWidget * parent = 0, const char * name = 0 );
		KFader( int minValue, int maxValue, int pageStep, int value, TQWidget * parent = 0, const char * name = 0 );

		virtual ~KFader();

		void setColor( TQColor & );

		virtual void setRange( int, int );
};

#endif /* KFADER_H */
